@@ -16,8 +16,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with the Gnome Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 /*
   @NOTATION@
@@ -35,9 +35,9 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <time.h>
+#include <glib.h>
 
 #ifdef HAVE_ESD
-#include <poll.h>
 #include <esd.h>
 #endif
 
@@ -421,7 +421,7 @@ gnome_sound_sample_load_audiofile(const char *file)
 static int
 send_all (int fd, const char *buf, size_t buflen)
 {
-	struct pollfd pfd[1];
+	GPollFD pfd[1];
 	size_t nwritten = 0;
 	int flags, rv;
 	ssize_t n;
@@ -431,13 +431,13 @@ send_all (int fd, const char *buf, size_t buflen)
 	
 	fcntl (fd, F_SETFL, flags | O_NONBLOCK);
 	
-	pfd[0].events = POLLOUT;
+	pfd[0].events = G_IO_OUT;
 	pfd[0].fd = fd;
 	
 	do {
 		do {
 			pfd[0].revents = 0;
-			rv = poll (pfd, 1, 100);
+			rv = g_poll (pfd, 1, 100);
 		} while (rv == -1 && (errno == EINTR || errno == EAGAIN));
 		
 		if (rv == -1) {
@@ -449,7 +449,7 @@ send_all (int fd, const char *buf, size_t buflen)
 			
 			fd = -1;
 			break;
-		} else if (rv < 1 || (pfd[0].revents & (POLLERR | POLLHUP | POLLOUT)) != POLLOUT) {
+		} else if (rv < 1 || (pfd[0].revents & (G_IO_ERR | G_IO_HUP | G_IO_OUT)) != G_IO_OUT) {
 			/* we /just/ lost the esd connection */
 			esd_close (fd);
 			fd = -1;
@@ -490,6 +490,8 @@ send_all (int fd, const char *buf, size_t buflen)
  *
  * Returns: The esound sample_id or %-1 if the sample was unable to be cached
  * for esound.
+ *
+ * @Deprecated: 2.30: Use ca_context_cache() or ca_context_cache_full() instead
  */
 int
 gnome_sound_sample_load(const char *sample_name, const char *filename)
@@ -564,6 +566,8 @@ gnome_sound_sample_load(const char *sample_name, const char *filename)
  *
  * Plays the audio stored in @filename, if possible. Fail quietly if playing is
  * not possible (due to missing sound support or for other reasons).
+ *
+ * @Deprecated: 2.30: Use ca_context_play(), ca_gtk_play_for_widget() or ca_gtk_play_for_event() instead
  */
 void
 gnome_sound_play (const char * filename)
@@ -602,6 +606,8 @@ gnome_sound_play (const char * filename)
  * @hostname: Hostname where esd daemon resides.
  *
  * Initialize the esd connection.
+ *
+ * @Deprecated: 2.30
  */
 void
 gnome_sound_init(const char *hostname)
@@ -617,6 +623,8 @@ gnome_sound_init(const char *hostname)
  * gnome_sound_shutdown:
  *
  * Shuts down the gnome sound support.
+ *
+ * @Deprecated: 2.30
  */
 void
 gnome_sound_shutdown(void)
@@ -638,6 +646,8 @@ gnome_sound_shutdown(void)
  *
  * Returns: the file descriptor of our esound connection or %-1
  * on error.
+ *
+ * @Deprecated: 2.30
  **/
 int
 gnome_sound_connection_get (void)
